################
Internal Classes
################

Page Object Helpers
===================
.. automodule:: holmium.core.pageobject 

.. autoclass:: ElementDict
    :members:

.. autoclass:: ElementList
    :members:

.. autoclass:: ElementGetter
    :members:

.. autofunction:: enhanced

.. automodule:: holmium.core.facets

.. autoclass:: FacetCollection
    :members:
.. autoclass:: Facet
    :members:
.. autoclass:: Faceted
    :members:
.. autoexception:: FacetError





Test configuration / execution
==============================
.. automodule:: holmium.core

.. autoclass:: HolmiumNose
    :members:

.. autoclass:: Config
    :members:

.. autoclass:: TestCase
    :members:

.. automodule:: holmium.core.config 

.. autoclass:: HolmiumConfig
    :members:



